import importlib
error_checker = importlib.import_module("fedcm.support.request-params-check")

def main(request, response):
  request_error = error_checker.tokenCheck(request)
  if (request_error):
    return request_error

  response.headers.set(b"Content-Type", b"application/json")
  response.headers.set(b"Access-Control-Allow-Origin", request.headers.get(b"Origin"))
  response.headers.set(b"Access-Control-Allow-Credentials", "true")

  account = request.POST.get(b"account_id").decode("utf-8")
  nonce = request.POST.get(b"nonce").decode("utf-8")
  if nonce == "token":
    return "{\"token\": \"account=%s\"}" % (account)
  return "{\"continue_on\": \"resolve.html?selected=%s&%s\"}" % (account, nonce)




from tests.support.asserts import assert_error

from . import uninstall_addon


def test_uninstall_nonexistent_addon(session):
    response = uninstall_addon(session, "i-do-not-exist-as-an-id")
    assert_error(response, "unknown error")



import importlib
import json
error_checker = importlib.import_module("fedcm.support.request-params-check")

def main(request, response):
  request_error = error_checker.tokenCheck(request)
  if (request_error):
    return request_error

  param_string = request.POST.get(b"params").decode("utf-8")
  param_obj = json.loads(param_string)
  if param_obj['a string'] != 'a value':
    return (550, [], "Incorrect parameters")

  response.headers.set(b"Content-Type", b"application/json")
  response.headers.set(b"Access-Control-Allow-Origin", request.headers.get(b"Origin"))
  response.headers.set(b"Access-Control-Allow-Credentials", "true")

  return "{\"token\": \"token\"}"
